# dnz

Client for determining domains/subdomains.

Installation instructions:

```bash
pip install dnz
```

```

Note
---------
dnz is not affiliated or endorsed by any of the web services it interacts with.